<?php
/**
 * Include and setup custom metaboxes and fields.
 *
 * @category YourThemeOrPlugin
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress
 */

add_filter( 'cmb_meta_boxes', 'crum_portfolio_metaboxes' );
/**
 * Define the metabox and field configurations.
 *
 * @param  array $meta_boxes
 * @return array
 */

function crum_portfolio_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = 'portfolio_';

    $meta_boxes[] = array(
        'id'         => 'portfolio-page-options',
        'title'      => __('Boxed Page background options','crum'),
        'pages'      => array( 'page', ), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_on' => array( 'key' => 'page-template', 'value' => array('tmp-portfolio-template-4-r.php','tmp-portfolio-template-4.php','tmp-portfolio-template-3.php','tmp-portfolio-template-2.php','tmp-portfolio-template-1.php','tmp-portfolio-masonry-sidebar.php','tmp-portfolio-masonry-4.php','tmp-portfolio-masonry.php') ),
        'show_names' => true, // Show field names on the left
        'fields'     => array(
            array(
                'name' => 'Display  of certain category?',
                'desc' => 'Check, if you want to display items from a certain category',
                'id'   => 'folio_sort_category',
                'type' => 'checkbox'
            ),
            array(
                'name' => 'Portfolio Category',
                'desc'	=> 'Select portfolio items category',
                'id'	=> 'folio_category',
                'taxonomy' => 'my-product_category',
                'type' => 'taxonomy_select',
            ),
            array(
                'name' => __('Number of items','crum'),
                'desc' => __('Number of portfolio items that will be show on page','crum'),
                'id' => $prefix . 'number_to_display',
                'type' => 'text'
            ),
        ),
    );

	$meta_boxes[] = array(
		'id'         => 'portfolio_custom_fields',
		'title'      => __('Portfolio Video','crum'),
		'pages'      => array('my-product'), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
            array(
                'name' => __('YouTube video ID','crum'),
                'desc'	=> '',
                'id'	=> 'folio_youtube_video_url',
                'type'	=> 'text'
            ),
            array(
                'name' =>  __('Vimeo video ID','crum'),
                'desc'	=> '',
                'id'	=> 'folio_vimeo_video_url',
                'type'	=> 'text'
            ),
            array(
                'name' =>  __('Self hosted video file in mp4 format','crum'),
                'desc'	=> '',
                'id'	=> 'folio_self_hosted_mp4',
                'type'	=> 'file'
            ),
            array(
                'name' =>  __('Self hosted video file in webM format','crum'),
                'desc'	=> '',
                'id'	=> 'folio_self_hosted_webm',
                'type'	=> 'file'
            )
		),
	);

 	// Add other metaboxes as needed

	return $meta_boxes;
}
